define([
    'streamhub-sdk/collection',
    'streamhub-sdk-tests/mocks/collection/mock-collection',
    'streamhub-sdk/collection/streams/archive',
    'streamhub-sdk/collection/streams/updater',
    'streamhub-sdk/collection/streams/writer',
    'streamhub-sdk/collection/featured-contents',
    'streamhub-sdk/content/views/content-list-view',
    'streamhub-sdk/content',
    'streamhub-sdk/auth',
    'stream/writable',
    'stream/readable'
], function (Collection, MockCollection, CollectionArchive,
CollectionUpdater, CollectionWriter, FeaturedContents, ContentListView, Content,
Auth, Writable, Readable) {
    'use strict';

    describe('streamhub-sdk/collection', function () {
        it('is a function', function () {
            expect(Collection).toEqual(jasmine.any(Function));
        });
        it('can be passed opts.writer on construction', function () {
            var writer = {};
            var collection = new Collection({
                writer: writer
            });
            expect(collection._writer).toBe(writer);
        });
        it('can be passed opts.id on construction', function () {
            var myId = '1234';
            var collection = new Collection({
                id: myId
            });
            expect(collection.id).toBe(myId);
        });
        describe('instance', function () {
            var opts,
                collection,
                mockInitResponse,
                mockPageResponse;
            beforeEach(function () {
                opts = {
                    network: 'test.fyre.co',
                    siteId: 'testSiteId',
                    articleId: 'testArticleId',
                    environment: 'test.livefyre.com'
                };
                // Mock bootstrapClient
                mockInitResponse = {"headDocument": {"content": [{"source": 5, "content": {"parentId": "", "bodyHtml": "<p>1 1372807378348</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372807378, "id": "26447946", "createdAt": 1372807378}, "vis": 1, "type": 0, "event": 1372807378824134, "childContent": []}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>0 1372781403976</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372781405, "id": "26447867", "createdAt": 1372781405}, "vis": 1, "type": 0, "event": 1372781405765515, "childContent": [{"source": 5, "content": {"parentId": "26447867", "bodyHtml": "<p>again</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372782591, "updatedAt": 1372782591, "id": "26447872", "ancestorId": "26447867"}, "vis": 1, "type": 0, "event": 1372782591730685, "childContent": []}, {"source": 5, "content": {"parentId": "26447867", "bodyHtml": "<p>hi</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372781991, "updatedAt": 1372781991, "id": "26447871", "ancestorId": "26447867"}, "vis": 1, "type": 0, "event": 1372781991509027, "childContent": []}]}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>3 1372778487471</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372778486, "id": "26447864", "createdAt": 1372778486}, "vis": 1, "type": 0, "event": 1372778486863027, "childContent": []}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>2 1372778058698</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372778057, "id": "26447862", "createdAt": 1372778057}, "vis": 1, "type": 0, "event": 1372778057942193, "childContent": []}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>4 1372778026533</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372778026, "id": "26447861", "createdAt": 1372778025}, "vis": 1, "type": 0, "event": 1372778026865713, "childContent": [{"source": 5, "content": {"parentId": "26447861", "bodyHtml": "<p>What</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372778435, "updatedAt": 1372778435, "id": "26447863", "ancestorId": "26447861"}, "vis": 1, "type": 0, "event": 1372778435650837, "childContent": []}]}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>as</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372777904, "id": "26447860", "createdAt": 1372777904}, "vis": 1, "type": 0, "event": 1372777904407292, "childContent": []}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>asd</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372777857, "id": "26447859", "createdAt": 1372777857}, "vis": 1, "type": 0, "event": 1372777857769119, "childContent": []}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>3 1372704030798</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372704031, "id": "26447748", "createdAt": 1372704030}, "vis": 1, "type": 0, "event": 1372704031892325, "childContent": [{"source": 5, "content": {"parentId": "26447748", "bodyHtml": "<p>Oh hello there!</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372785029, "updatedAt": 1372785030, "id": "26447882", "ancestorId": "26447748"}, "vis": 1, "type": 0, "event": 1372785030228859, "childContent": []}, {"source": 5, "content": {"parentId": "26447748", "bodyHtml": "<p>wow</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372714512, "updatedAt": 1372714512, "id": "26447785", "ancestorId": "26447748"}, "vis": 1, "type": 0, "event": 1372714512644579, "childContent": []}, {"source": 5, "content": {"parentId": "26447748", "bodyHtml": "<p>boy that was insightful</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372713133, "updatedAt": 1372713134, "id": "26447776", "ancestorId": "26447748"}, "vis": 1, "type": 0, "event": 1372713134175552, "childContent": []}, {"source": 5, "content": {"parentId": "26447748", "bodyHtml": "<p>jukhjh</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372712859, "updatedAt": 1372712859, "id": "26447774", "ancestorId": "26447748"}, "vis": 1, "type": 0, "event": 1372712860128520, "childContent": []}, {"source": 5, "content": {"parentId": "26447748", "bodyHtml": "<p>asdf</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372704033, "updatedAt": 1372704033, "id": "26447749", "ancestorId": "26447748"}, "vis": 1, "type": 0, "event": 1372704034267233, "childContent": []}]}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>1 1372703334982</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372703335, "id": "26447746", "createdAt": 1372703335}, "vis": 1, "type": 0, "event": 1372703336111790, "childContent": [{"source": 5, "content": {"parentId": "26447746", "bodyHtml": "<p>and one more?</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372789001, "updatedAt": 1372789001, "id": "26447896", "ancestorId": "26447746"}, "vis": 1, "type": 0, "event": 1372789001596891, "childContent": []}, {"source": 5, "content": {"parentId": "26447746", "bodyHtml": "<p>nm</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372713924, "updatedAt": 1372713924, "id": "26447784", "ancestorId": "26447746"}, "vis": 1, "type": 0, "event": 1372713924495484, "childContent": []}, {"source": 5, "content": {"parentId": "26447746", "bodyHtml": "<p>help me pls</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372712117, "updatedAt": 1372712117, "id": "26447772", "ancestorId": "26447746"}, "vis": 1, "type": 0, "event": 1372712117995803, "childContent": []}, {"source": 5, "content": {"parentId": "26447746", "bodyHtml": "<p>gene</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372712111, "updatedAt": 1372712111, "id": "26447771", "ancestorId": "26447746"}, "vis": 1, "type": 0, "event": 1372712111683578, "childContent": []}, {"source": 5, "content": {"parentId": "26447746", "bodyHtml": "<p>adslkjag</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372712105, "updatedAt": 1372712105, "id": "26447770", "ancestorId": "26447746"}, "vis": 1, "type": 0, "event": 1372712105685205, "childContent": []}, {"source": 5, "content": {"parentId": "26447746", "bodyHtml": "<p>ffsdf</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372712101, "updatedAt": 1372712101, "id": "26447769", "ancestorId": "26447746"}, "vis": 1, "type": 0, "event": 1372712101991395, "childContent": []}, {"source": 5, "content": {"parentId": "26447746", "bodyHtml": "<p>asdf 1372712029765</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372712030, "updatedAt": 1372712030, "id": "26447768", "ancestorId": "26447746"}, "vis": 1, "type": 0, "event": 1372712030297834, "childContent": []}, {"source": 5, "content": {"parentId": "26447746", "bodyHtml": "<p>asdf 1372711258543</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372711258, "updatedAt": 1372711258, "id": "26447763", "ancestorId": "26447746"}, "vis": 1, "type": 0, "event": 1372711259128446, "childContent": []}, {"source": 5, "content": {"parentId": "26447746", "bodyHtml": "<p>asdf</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372703336, "updatedAt": 1372703336, "id": "26447747", "ancestorId": "26447746"}, "vis": 1, "type": 0, "event": 1372703337262164, "childContent": []}]}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>0 1372703328752</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372703329, "id": "26447744", "createdAt": 1372703329}, "vis": 1, "type": 0, "event": 1372703329822076, "childContent": [{"source": 5, "content": {"parentId": "26447744", "bodyHtml": "<p>asdf</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372703330, "updatedAt": 1372703330, "id": "26447745", "ancestorId": "26447744"}, "vis": 1, "type": 0, "event": 1372703331394509, "childContent": []}]}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>0 1372703292931</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372703293, "id": "26447742", "createdAt": 1372703293}, "vis": 1, "type": 0, "event": 1372703293900419, "childContent": [{"source": 5, "content": {"parentId": "26447742", "bodyHtml": "<p>asdf</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372703295, "updatedAt": 1372703295, "id": "26447743", "ancestorId": "26447742"}, "vis": 1, "type": 0, "event": 1372703295859160, "childContent": []}]}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>0 1372703283084</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372703283, "id": "26447741", "createdAt": 1372703283}, "vis": 1, "type": 0, "event": 1372703284145888, "childContent": []}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>0 1372703259644</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372703259, "id": "26447739", "createdAt": 1372703259}, "vis": 1, "type": 0, "event": 1372703260597819, "childContent": [{"source": 5, "content": {"parentId": "26447739", "bodyHtml": "<p>asdf</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372703261, "updatedAt": 1372703261, "id": "26447740", "ancestorId": "26447739"}, "vis": 1, "type": 0, "event": 1372703262301630, "childContent": []}]}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>2 1372702839981</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372702841, "id": "26447737", "createdAt": 1372702841}, "vis": 1, "type": 0, "event": 1372702842456030, "childContent": [{"source": 5, "content": {"parentId": "26447737", "bodyHtml": "<p>vjhbv</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372713062, "updatedAt": 1372713062, "id": "26447775", "ancestorId": "26447737"}, "vis": 1, "type": 0, "event": 1372713063106834, "childContent": []}, {"source": 5, "content": {"parentId": "26447737", "bodyHtml": "<p>asdf 1372711139621</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372711139, "updatedAt": 1372711140, "id": "26447762", "ancestorId": "26447737"}, "vis": 1, "type": 0, "event": 1372711140372281, "childContent": []}, {"source": 5, "content": {"parentId": "26447737", "bodyHtml": "<p>asdf 1372709260088</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372709260, "updatedAt": 1372709260, "id": "26447753", "ancestorId": "26447737"}, "vis": 1, "type": 0, "event": 1372709260565058, "childContent": []}, {"source": 5, "content": {"parentId": "26447737", "bodyHtml": "<p>asdf</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372702843, "updatedAt": 1372702843, "id": "26447738", "ancestorId": "26447737"}, "vis": 1, "type": 0, "event": 1372702843797587, "childContent": []}]}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>0 1372702682316</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372702686, "id": "26447735", "createdAt": 1372702686}, "vis": 1, "type": 0, "event": 1372702686931099, "childContent": [{"source": 5, "content": {"parentId": "26447735", "bodyHtml": "<p>asdf</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372702688, "updatedAt": 1372702688, "id": "26447736", "ancestorId": "26447735"}, "vis": 1, "type": 0, "event": 1372702689041992, "childContent": []}]}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>0 1372702303895</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372702301, "id": "26447733", "createdAt": 1372702300}, "vis": 1, "type": 0, "event": 1372702301681285, "childContent": [{"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>stream quickly pls</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372788991, "updatedAt": 1372788991, "id": "26447895", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372788992101458, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>bam! indeed</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372787751, "updatedAt": 1372787751, "id": "26447894", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372787751910104, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>asdfe333</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372787639, "updatedAt": 1372787639, "id": "26447893", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372787639502487, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>gaggaaa</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372787050, "updatedAt": 1372787050, "id": "26447892", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372787050300324, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>asldkfljasdf</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372786675, "updatedAt": 1372786675, "id": "26447891", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372786675685834, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>ace</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372786197, "updatedAt": 1372786197, "id": "26447890", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372786197615157, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>eeeerrrrrrrr</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372786130, "updatedAt": 1372786130, "id": "26447889", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372786131003617, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>asdfaseeeee</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372786033, "updatedAt": 1372786033, "id": "26447888", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372786033899802, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>testy</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372785971, "updatedAt": 1372785971, "id": "26447887", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372785971576983, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>once again</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372785899, "updatedAt": 1372785899, "id": "26447886", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372785899797464, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>yeah yeah</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372785788, "updatedAt": 1372785788, "id": "26447885", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372785789117862, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>gene gene gene 3</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372785766, "updatedAt": 1372785766, "id": "26447884", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372785766672297, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>gene gene gene</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372785754, "updatedAt": 1372785755, "id": "26447883", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372785755360361, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>no body</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372784376, "updatedAt": 1372784376, "id": "26447881", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372784376320420, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>asdfasdfasdf</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372783735, "updatedAt": 1372783735, "id": "26447878", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372783735820433, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>gssdf</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372783707, "updatedAt": 1372783708, "id": "26447876", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372783708230680, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>clothes again 2</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372783654, "updatedAt": 1372783654, "id": "26447875", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372783654514543, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>clothes again</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372783637, "updatedAt": 1372783637, "id": "26447874", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372783638113650, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>Oh. Shit.</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372724323, "updatedAt": 1372724323, "id": "26447794", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372724323603019, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>This is the shit.</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372714901, "updatedAt": 1372714901, "id": "26447787", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372714901592472, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>put it on ebay!!! pls</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372712599, "updatedAt": 1372712599, "id": "26447773", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372712600154560, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>asdf 1372710986926</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372710987, "updatedAt": 1372710987, "id": "26447761", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372710987453705, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>asdf 1372710963003</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372710963, "updatedAt": 1372710963, "id": "26447760", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372710963568013, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>asdf 1372710901267</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372710901, "updatedAt": 1372710901, "id": "26447759", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372710901840190, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>asdf 1372710848870</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372710849, "updatedAt": 1372710849, "id": "26447758", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372710849309361, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>asdf 1372710845069</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372710845, "updatedAt": 1372710845, "id": "26447757", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372710845603555, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>asdf 1372710773907</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372710774, "updatedAt": 1372710774, "id": "26447756", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372710774458637, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>asdf 1372710406493</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372710406, "updatedAt": 1372710406, "id": "26447754", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372710407227233, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>asdf 1372709251249</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372709251, "updatedAt": 1372709251, "id": "26447752", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372709251698365, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>asdf 1372709220760</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372709220, "updatedAt": 1372709221, "id": "26447751", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372709221854376, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>asdf 1372704197627</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372704197, "updatedAt": 1372704197, "id": "26447750", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372704198684578, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>asdf</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372702302, "updatedAt": 1372702302, "id": "26447734", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372702302898773, "childContent": []}]}], "authors": {"system@labs-t402.fyre.co": {"displayName": "system", "tags": [], "profileUrl": "", "avatar": "http://gravatar.com/avatar/e23293c6dfc25b86762b045336233add/?s=50&d=http://avatars-staging.fyre.co/a/anon/50.jpg", "type": 1, "id": "system@labs-t402.fyre.co"}}, "followers": ["system@labs-t402.fyre.co"], "isComplete": false}, "siteSettings": {"nestLevel": 4, "enabled": true, "__modified__": 1371506702.450499, "premoderated": false, "allowGuestComments": false}, "networkSettings": {"highVelocityMode": false, "mediaDisplay": 1, "allowEditComments": false, "richTextEnabled": true, "editCommentInterval": 5, "allowGuestComments": false, "liShareEnabled": false, "enabled": true, "fbShareEnabled": true, "hovercardsEnabled": true, "nestLevel": 4, "streamType": 1, "throttleStream": false, "repliesEnabled": true, "premoderated": false, "topContentDisplay": 1, "commentsEnabled": true, "charLimit": 8000, "twitterShareEnabled": true, "rawHtml": false, "__modified__": 1371779372.99041}, "collectionSettings": {"networkId": "labs-t402.fyre.co", "archiveInfo": {"nPages": 1, "pageInfo": {"1": {"url": "/t402.livefyre.com/labs-t402.fyre.co/303827/Y29udGV4dHVhbF8x/1.json", "last": 1372807378, "first": 1372777857}, "0": {"url": "/t402.livefyre.com/labs-t402.fyre.co/303827/Y29udGV4dHVhbF8x/0.json", "last": 1372704030, "first": 1372469583}}, "pathBase": "/t402.livefyre.com/labs-t402.fyre.co/303827/Y29udGV4dHVhbF8x/"}, "allowEditComments": false, "collectionId": "10712944", "url": "", "checksum": "", "bootstrapUrl": "/t402.livefyre.com/labs-t402.fyre.co/303827/Y29udGV4dHVhbF8x/head.json", "title": "", "numVisible": 114, "nestLevel": 0, "siteId": "303827", "commentsDisabled": false, "allowGuestComments": false, "followers": 1, "config": {"__modified__": 1372807410.134516}, "data": [], "event": 1372807378824134, "editCommentInterval": 0}};
                mockPageResponse = {"content": [{"source": 5, "content": {"parentId": "", "bodyHtml": "<p>3 1372704030798</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372704031, "id": "26447748", "createdAt": 1372704030}, "vis": 1, "type": 0, "event": 1372704031892325, "childContent": [{"source": 5, "content": {"parentId": "26447748", "bodyHtml": "<p>Oh hello there!</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372785029, "updatedAt": 1372785030, "id": "26447882", "ancestorId": "26447748"}, "vis": 1, "type": 0, "event": 1372785030228859, "childContent": []}, {"source": 5, "content": {"parentId": "26447748", "bodyHtml": "<p>wow</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372714512, "updatedAt": 1372714512, "id": "26447785", "ancestorId": "26447748"}, "vis": 1, "type": 0, "event": 1372714512644579, "childContent": []}, {"source": 5, "content": {"parentId": "26447748", "bodyHtml": "<p>boy that was insightful</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372713133, "updatedAt": 1372713134, "id": "26447776", "ancestorId": "26447748"}, "vis": 1, "type": 0, "event": 1372713134175552, "childContent": []}, {"source": 5, "content": {"parentId": "26447748", "bodyHtml": "<p>jukhjh</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372712859, "updatedAt": 1372712859, "id": "26447774", "ancestorId": "26447748"}, "vis": 1, "type": 0, "event": 1372712860128520, "childContent": []}, {"source": 5, "content": {"parentId": "26447748", "bodyHtml": "<p>asdf</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372704033, "updatedAt": 1372704033, "id": "26447749", "ancestorId": "26447748"}, "vis": 1, "type": 0, "event": 1372704034267233, "childContent": []}]}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>1 1372703334982</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372703335, "id": "26447746", "createdAt": 1372703335}, "vis": 1, "type": 0, "event": 1372703336111790, "childContent": [{"source": 5, "content": {"parentId": "26447746", "bodyHtml": "<p>and one more?</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372789001, "updatedAt": 1372789001, "id": "26447896", "ancestorId": "26447746"}, "vis": 1, "type": 0, "event": 1372789001596891, "childContent": []}, {"source": 5, "content": {"parentId": "26447746", "bodyHtml": "<p>nm</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372713924, "updatedAt": 1372713924, "id": "26447784", "ancestorId": "26447746"}, "vis": 1, "type": 0, "event": 1372713924495484, "childContent": []}, {"source": 5, "content": {"parentId": "26447746", "bodyHtml": "<p>help me pls</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372712117, "updatedAt": 1372712117, "id": "26447772", "ancestorId": "26447746"}, "vis": 1, "type": 0, "event": 1372712117995803, "childContent": []}, {"source": 5, "content": {"parentId": "26447746", "bodyHtml": "<p>gene</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372712111, "updatedAt": 1372712111, "id": "26447771", "ancestorId": "26447746"}, "vis": 1, "type": 0, "event": 1372712111683578, "childContent": []}, {"source": 5, "content": {"parentId": "26447746", "bodyHtml": "<p>adslkjag</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372712105, "updatedAt": 1372712105, "id": "26447770", "ancestorId": "26447746"}, "vis": 1, "type": 0, "event": 1372712105685205, "childContent": []}, {"source": 5, "content": {"parentId": "26447746", "bodyHtml": "<p>ffsdf</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372712101, "updatedAt": 1372712101, "id": "26447769", "ancestorId": "26447746"}, "vis": 1, "type": 0, "event": 1372712101991395, "childContent": []}, {"source": 5, "content": {"parentId": "26447746", "bodyHtml": "<p>asdf 1372712029765</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372712030, "updatedAt": 1372712030, "id": "26447768", "ancestorId": "26447746"}, "vis": 1, "type": 0, "event": 1372712030297834, "childContent": []}, {"source": 5, "content": {"parentId": "26447746", "bodyHtml": "<p>asdf 1372711258543</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372711258, "updatedAt": 1372711258, "id": "26447763", "ancestorId": "26447746"}, "vis": 1, "type": 0, "event": 1372711259128446, "childContent": []}, {"source": 5, "content": {"parentId": "26447746", "bodyHtml": "<p>asdf</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372703336, "updatedAt": 1372703336, "id": "26447747", "ancestorId": "26447746"}, "vis": 1, "type": 0, "event": 1372703337262164, "childContent": []}]}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>0 1372703328752</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372703329, "id": "26447744", "createdAt": 1372703329}, "vis": 1, "type": 0, "event": 1372703329822076, "childContent": [{"source": 5, "content": {"parentId": "26447744", "bodyHtml": "<p>asdf</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372703330, "updatedAt": 1372703330, "id": "26447745", "ancestorId": "26447744"}, "vis": 1, "type": 0, "event": 1372703331394509, "childContent": []}]}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>0 1372703292931</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372703293, "id": "26447742", "createdAt": 1372703293}, "vis": 1, "type": 0, "event": 1372703293900419, "childContent": [{"source": 5, "content": {"parentId": "26447742", "bodyHtml": "<p>asdf</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372703295, "updatedAt": 1372703295, "id": "26447743", "ancestorId": "26447742"}, "vis": 1, "type": 0, "event": 1372703295859160, "childContent": []}]}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>0 1372703283084</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372703283, "id": "26447741", "createdAt": 1372703283}, "vis": 1, "type": 0, "event": 1372703284145888, "childContent": []}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>0 1372703259644</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372703259, "id": "26447739", "createdAt": 1372703259}, "vis": 1, "type": 0, "event": 1372703260597819, "childContent": [{"source": 5, "content": {"parentId": "26447739", "bodyHtml": "<p>asdf</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372703261, "updatedAt": 1372703261, "id": "26447740", "ancestorId": "26447739"}, "vis": 1, "type": 0, "event": 1372703262301630, "childContent": []}]}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>2 1372702839981</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372702841, "id": "26447737", "createdAt": 1372702841}, "vis": 1, "type": 0, "event": 1372702842456030, "childContent": [{"source": 5, "content": {"parentId": "26447737", "bodyHtml": "<p>vjhbv</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372713062, "updatedAt": 1372713062, "id": "26447775", "ancestorId": "26447737"}, "vis": 1, "type": 0, "event": 1372713063106834, "childContent": []}, {"source": 5, "content": {"parentId": "26447737", "bodyHtml": "<p>asdf 1372711139621</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372711139, "updatedAt": 1372711140, "id": "26447762", "ancestorId": "26447737"}, "vis": 1, "type": 0, "event": 1372711140372281, "childContent": []}, {"source": 5, "content": {"parentId": "26447737", "bodyHtml": "<p>asdf 1372709260088</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372709260, "updatedAt": 1372709260, "id": "26447753", "ancestorId": "26447737"}, "vis": 1, "type": 0, "event": 1372709260565058, "childContent": []}, {"source": 5, "content": {"parentId": "26447737", "bodyHtml": "<p>asdf</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372702843, "updatedAt": 1372702843, "id": "26447738", "ancestorId": "26447737"}, "vis": 1, "type": 0, "event": 1372702843797587, "childContent": []}]}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>0 1372702682316</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372702686, "id": "26447735", "createdAt": 1372702686}, "vis": 1, "type": 0, "event": 1372702686931099, "childContent": [{"source": 5, "content": {"parentId": "26447735", "bodyHtml": "<p>asdf</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372702688, "updatedAt": 1372702688, "id": "26447736", "ancestorId": "26447735"}, "vis": 1, "type": 0, "event": 1372702689041992, "childContent": []}]}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>0 1372702303895</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372702301, "id": "26447733", "createdAt": 1372702300}, "vis": 1, "type": 0, "event": 1372702301681285, "childContent": [{"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>stream quickly pls</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372788991, "updatedAt": 1372788991, "id": "26447895", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372788992101458, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>bam! indeed</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372787751, "updatedAt": 1372787751, "id": "26447894", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372787751910104, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>asdfe333</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372787639, "updatedAt": 1372787639, "id": "26447893", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372787639502487, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>gaggaaa</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372787050, "updatedAt": 1372787050, "id": "26447892", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372787050300324, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>asldkfljasdf</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372786675, "updatedAt": 1372786675, "id": "26447891", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372786675685834, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>ace</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372786197, "updatedAt": 1372786197, "id": "26447890", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372786197615157, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>eeeerrrrrrrr</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372786130, "updatedAt": 1372786130, "id": "26447889", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372786131003617, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>asdfaseeeee</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372786033, "updatedAt": 1372786033, "id": "26447888", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372786033899802, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>testy</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372785971, "updatedAt": 1372785971, "id": "26447887", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372785971576983, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>once again</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372785899, "updatedAt": 1372785899, "id": "26447886", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372785899797464, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>yeah yeah</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372785788, "updatedAt": 1372785788, "id": "26447885", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372785789117862, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>gene gene gene 3</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372785766, "updatedAt": 1372785766, "id": "26447884", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372785766672297, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>gene gene gene</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372785754, "updatedAt": 1372785755, "id": "26447883", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372785755360361, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>no body</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372784376, "updatedAt": 1372784376, "id": "26447881", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372784376320420, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>asdfasdfasdf</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372783735, "updatedAt": 1372783735, "id": "26447878", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372783735820433, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>gssdf</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372783707, "updatedAt": 1372783708, "id": "26447876", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372783708230680, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>clothes again 2</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372783654, "updatedAt": 1372783654, "id": "26447875", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372783654514543, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>clothes again</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372783637, "updatedAt": 1372783637, "id": "26447874", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372783638113650, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>Oh. Shit.</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372724323, "updatedAt": 1372724323, "id": "26447794", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372724323603019, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>This is the shit.</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372714901, "updatedAt": 1372714901, "id": "26447787", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372714901592472, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>put it on ebay!!! pls</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372712599, "updatedAt": 1372712599, "id": "26447773", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372712600154560, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>asdf 1372710986926</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372710987, "updatedAt": 1372710987, "id": "26447761", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372710987453705, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>asdf 1372710963003</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372710963, "updatedAt": 1372710963, "id": "26447760", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372710963568013, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>asdf 1372710901267</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372710901, "updatedAt": 1372710901, "id": "26447759", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372710901840190, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>asdf 1372710848870</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372710849, "updatedAt": 1372710849, "id": "26447758", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372710849309361, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>asdf 1372710845069</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372710845, "updatedAt": 1372710845, "id": "26447757", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372710845603555, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>asdf 1372710773907</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372710774, "updatedAt": 1372710774, "id": "26447756", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372710774458637, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>asdf 1372710406493</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372710406, "updatedAt": 1372710406, "id": "26447754", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372710407227233, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>asdf 1372709251249</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372709251, "updatedAt": 1372709251, "id": "26447752", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372709251698365, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>asdf 1372709220760</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372709220, "updatedAt": 1372709221, "id": "26447751", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372709221854376, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>asdf 1372704197627</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372704197, "updatedAt": 1372704197, "id": "26447750", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372704198684578, "childContent": []}, {"source": 5, "content": {"parentId": "26447733", "bodyHtml": "<p>asdf</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372702302, "updatedAt": 1372702302, "id": "26447734", "ancestorId": "26447733"}, "vis": 1, "type": 0, "event": 1372702302898773, "childContent": []}]}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>-1 1372702290293</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372702285, "id": "26447731", "createdAt": 1372702285}, "vis": 1, "type": 0, "event": 1372702286473165, "childContent": [{"source": 5, "content": {"parentId": "26447731", "bodyHtml": "<p>asdf</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372702287, "updatedAt": 1372702288, "id": "26447732", "ancestorId": "26447731"}, "vis": 1, "type": 0, "event": 1372702288465975, "childContent": []}]}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>5 1372702033098</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372702029, "id": "26447729", "createdAt": 1372702029}, "vis": 1, "type": 0, "event": 1372702030763991, "childContent": []}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>4 1372700758411</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372700753, "id": "26447728", "createdAt": 1372700753}, "vis": 1, "type": 0, "event": 1372700753663399, "childContent": []}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>4 1372700719944</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372700716, "id": "26447727", "createdAt": 1372700715}, "vis": 1, "type": 0, "event": 1372700716759324, "childContent": []}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>4 1372700577964</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372700603, "id": "26447725", "createdAt": 1372700603}, "vis": 1, "type": 0, "event": 1372700603619242, "childContent": [{"source": 5, "content": {"parentId": "26447725", "bodyHtml": "<p>asdf</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372700607, "updatedAt": 1372700607, "id": "26447726", "ancestorId": "26447725"}, "vis": 1, "type": 0, "event": 1372700607768577, "childContent": []}]}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>4 1372700577964</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372700574, "id": "26447723", "createdAt": 1372700574}, "vis": 1, "type": 0, "event": 1372700574981380, "childContent": [{"source": 5, "content": {"parentId": "26447723", "bodyHtml": "<p>asdf</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372700579, "updatedAt": 1372700580, "id": "26447724", "ancestorId": "26447723"}, "vis": 1, "type": 0, "event": 1372700580595139, "childContent": []}]}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>asdf</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372699851, "id": "26447717", "createdAt": 1372699851}, "vis": 1, "type": 0, "event": 1372699851746921, "childContent": []}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>4 1372699785164</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372699780, "id": "26447716", "createdAt": 1372699780}, "vis": 1, "type": 0, "event": 1372699781452255, "childContent": []}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>asdf</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372699627, "id": "26447714", "createdAt": 1372699627}, "vis": 1, "type": 0, "event": 1372699628321137, "childContent": []}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>4 1372699614172</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372699625, "id": "26447713", "createdAt": 1372699625}, "vis": 1, "type": 0, "event": 1372699626513207, "childContent": []}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>asdf</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372699539, "id": "26447712", "createdAt": 1372699539}, "vis": 1, "type": 0, "event": 1372699540163582, "childContent": []}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>4 1372699540734</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372699536, "id": "26447711", "createdAt": 1372699536}, "vis": 1, "type": 0, "event": 1372699537278133, "childContent": []}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>4</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372698888, "id": "26447710", "createdAt": 1372698888}, "vis": 1, "type": 0, "event": 1372698888966079, "childContent": []}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>asdf</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372698835, "id": "26447709", "createdAt": 1372698835}, "vis": 1, "type": 0, "event": 1372698836336422, "childContent": []}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>4</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372698760, "id": "26447708", "createdAt": 1372698760}, "vis": 1, "type": 0, "event": 1372698761040228, "childContent": []}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>asdf</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372698724, "id": "26447707", "createdAt": 1372698724}, "vis": 1, "type": 0, "event": 1372698724874347, "childContent": []}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>4</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372698722, "id": "26447706", "createdAt": 1372698722}, "vis": 1, "type": 0, "event": 1372698723390362, "childContent": []}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>asdf</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372698596, "id": "26447705", "createdAt": 1372698596}, "vis": 1, "type": 0, "event": 1372698597081799, "childContent": []}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>4</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372698594, "id": "26447704", "createdAt": 1372698594}, "vis": 1, "type": 0, "event": 1372698595733206, "childContent": []}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>asdf</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372697168, "id": "26447702", "createdAt": 1372697168}, "vis": 1, "type": 0, "event": 1372697169382728, "childContent": []}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>4</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372697166, "id": "26447701", "createdAt": 1372697166}, "vis": 1, "type": 0, "event": 1372697167806108, "childContent": []}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>asdf</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372697091, "id": "26447700", "createdAt": 1372697091}, "vis": 1, "type": 0, "event": 1372697091541497, "childContent": []}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>4</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372697088, "id": "26447699", "createdAt": 1372697088}, "vis": 1, "type": 0, "event": 1372697089858251, "childContent": []}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>asdf</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372676628, "id": "26447651", "createdAt": 1372676628}, "vis": 1, "type": 0, "event": 1372676628668103, "childContent": []}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>4</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372676625, "id": "26447650", "createdAt": 1372676624}, "vis": 1, "type": 0, "event": 1372676627266584, "childContent": []}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>asdf</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372470002, "id": "26447626", "createdAt": 1372470002}, "vis": 1, "type": 0, "event": 1372470003237539, "childContent": []}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>4</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372469998, "id": "26447625", "createdAt": 1372469998}, "vis": 1, "type": 0, "event": 1372470001163888, "childContent": []}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>asdf</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372469608, "id": "26447624", "createdAt": 1372469608}, "vis": 1, "type": 0, "event": 1372469608882435, "childContent": []}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>4</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372469606, "id": "26447623", "createdAt": 1372469606}, "vis": 1, "type": 0, "event": 1372469607243097, "childContent": []}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>asdf</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372469590, "id": "26447622", "createdAt": 1372469590}, "vis": 1, "type": 0, "event": 1372469591296455, "childContent": []}, {"source": 5, "content": {"parentId": "", "bodyHtml": "<p>4</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "updatedAt": 1372469583, "id": "26447621", "createdAt": 1372469583}, "vis": 1, "type": 0, "event": 1372469587101917, "childContent": [{"source": 5, "content": {"parentId": "26447621", "bodyHtml": "<p>sdfsdfsd </p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372793876, "updatedAt": 1372793876, "id": "26447904", "ancestorId": "26447621"}, "vis": 1, "type": 0, "event": 1372793876296518, "childContent": []}, {"source": 5, "content": {"parentId": "26447621", "bodyHtml": "<p>Oh hello there</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372790517, "updatedAt": 1372790517, "id": "26447897", "ancestorId": "26447621"}, "vis": 1, "type": 0, "event": 1372790517703187, "childContent": []}, {"source": 5, "content": {"parentId": "26447621", "bodyHtml": "<p>Oh. my. god</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372724337, "updatedAt": 1372724337, "id": "26447795", "ancestorId": "26447621"}, "vis": 1, "type": 0, "event": 1372724337377464, "childContent": []}, {"source": 5, "content": {"parentId": "26447621", "bodyHtml": "<p>asdf 1372711502888</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372711503, "updatedAt": 1372711503, "id": "26447767", "ancestorId": "26447621"}, "vis": 1, "type": 0, "event": 1372711503367643, "childContent": []}, {"source": 5, "content": {"parentId": "26447621", "bodyHtml": "<p>asdf 1372711496451</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372711496, "updatedAt": 1372711496, "id": "26447766", "ancestorId": "26447621"}, "vis": 1, "type": 0, "event": 1372711496957215, "childContent": []}, {"source": 5, "content": {"parentId": "26447621", "bodyHtml": "<p>asdf 1372711490619</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372711490, "updatedAt": 1372711490, "id": "26447765", "ancestorId": "26447621"}, "vis": 1, "type": 0, "event": 1372711491303393, "childContent": []}, {"source": 5, "content": {"parentId": "26447621", "bodyHtml": "<p>asdf 1372711486241</p>", "annotations": {"moderator": true, "procurementmeta": [{"networkId": "labs-t402.fyre.co", "siteId": "303827", "collectionRuleId": "10712944@fyre.io", "collectionId": "10712944"}]}, "authorId": "system@labs-t402.fyre.co", "createdAt": 1372711486, "updatedAt": 1372711487, "id": "26447764", "ancestorId": "26447621"}, "vis": 1, "type": 0, "event": 1372711487730230, "childContent": []}]}], "meta": {"last": 1372704030, "idx": 0, "first": 1372469583}, "authors": {"system@labs-t402.fyre.co": {"displayName": "system", "tags": [], "profileUrl": "", "avatar": "http://gravatar.com/avatar/e23293c6dfc25b86762b045336233add/?s=50&d=http://avatars-staging.fyre.co/a/anon/50.jpg", "type": 1, "id": "system@labs-t402.fyre.co"}}};
                opts.bootstrapClient = {
                    getContent: jasmine.createSpy().andCallFake(function (opts, errback) {
                        errback(null, typeof opts.page !== 'undefined' ? mockPageResponse : mockInitResponse);
                    })
                };
                collection = new Collection(opts);
            });

            it('has .network', function () {
                expect(collection.network).toBe(opts.network);
            });
            it('has .siteId', function () {
                expect(collection.siteId).toBe(opts.siteId);
            });
            it('has .articleId', function () {
                expect(collection.articleId).toBe(opts.articleId);
            });
            it('has .environment', function () {
                expect(collection.environment).toBe(opts.environment);
            });

            describe('.createArchive', function () {
                it('returns a readable CollectionArchive Stream', function () {
                    var archive = collection.createArchive();
                    expect(archive instanceof CollectionArchive).toBe(true);
                });
            });

            describe('.createUpdater', function () {
                it('returns a readable CollectionUpdater Stream', function () {
                    var updater = collection.createUpdater();
                    expect(updater instanceof CollectionUpdater).toBe(true);
                });
            });

            describe('.createWriter', function () {
                it('returns a writable CollectionWriter Stream', function () {
                    var writer = collection.createWriter();
                    expect(writer instanceof CollectionWriter).toBe(true);
                });
            });
            
            describe('.initFromBootstrap', function () {
                var opts,
                    collection,
                    mock404Response,
                    mock400Response,
                    mock500Response,
                    mock200Response,
                    mock202Response,
                    fnSuccessfulInit,
                    fnFailedInit,
                    fnSuccessfulCreate,
                    fnFailedCreate,
                    fnServerError,
                    fnCallback;
                beforeEach(function () {
                    opts = {
                        network: 'test.fyre.co',
                        siteId: 'testSiteId',
                        articleId: 'testArticleId',
                        environment: 'test.livefyre.com',
                        collectionMeta: {
                            title: 'SDK Test',
                            url: 'http://test.fyre.co',
                            tags: ['test', 'SDK']
                        },
                        signed: false
                    };
                    //Faked responses
                    mock404Response = "Not Found";//{"msg": "", "status": "error", "error_type": "ResourceDoesNotExist", "trace": "Traceback (most recent call last):\n  File... raise ResourceDoesNotExist()\nResourceNotFoundError\n", "code": 404};
                    mock400Response = "Bad Request";//{"msg": "Cannot create a collection without an articleId: {\"url\": \"http://www.fake.com\", \"tags\": \"test,wall\", \"title\": \"Media Wall Example\"}.", "status": "error", "error_type": "BadRequestError", "trace": "Traceback (most recent call last):\n  File... raise BadRequestError(\"Cannot create a collection without an articleId: %s.\" % json.dumps(collection_meta))\nBadDataError: Cannot create a collection without an articleId: {\"url\": \"http://www.fake.com\", \"tags\": \"test,wall\", \"title\": \"Media Wall Example\"}.\n", "code": 400}
                    mock500Response = "Internal Server Error";//{"msg": "", "status": "error", "code": 500};
                    mock200Response = "OK";//{};//Sometimes sent by our servers in leu of an error.
                    mock202Response = {"msg": "This request is being processed.", "status": "ok", "code": 202};
                    
                    //Faked response callbacks
                    fnSuccessfulInit = function (opts, errback) { errback(null, mockInitResponse); };
                    fnFailedInit= function (opts, errback) { errback(mock404Response); };
                    fnSuccessfulCreate= function (opts, errback) { errback(null, mock202Response); };
                    fnFailedCreate= function (opts, errback) { errback(mock400Response); };
                    fnServerError= function (opts, errback) { errback(mock500Response); };
                    
                    //Use spy to check callbacks
                    fnCallback = jasmine.createSpy();
                    
                    collection = new Collection(opts);
                });
                
                it('reads from existing collections', function () {
                    spyOn(collection._bootstrapClient, "getContent").andCallFake(fnSuccessfulInit);
                    
                    collection.initFromBootstrap(fnCallback);
                    
                    expect(collection._bootstrapClient.getContent).toHaveBeenCalled();
                    expect(fnCallback).toHaveBeenCalledWith(null, mockInitResponse);
                });
                
                it('creates and reads from a new collection when a current collection isn\'t found', function () {
                    var spyGetContent = spyOn(collection._bootstrapClient, "getContent").andCallFake(fnFailedInit);
                    spyOn(collection._createClient, "createCollection").andCallFake(function (opts, errback) {
                        spyGetContent.andCallFake(fnSuccessfulInit);
                        fnSuccessfulCreate(opts, errback);
                    });
                    
                    collection.initFromBootstrap(fnCallback);
                    
                    expect(collection._bootstrapClient.getContent.calls.length).toEqual(2);
                    expect(collection._createClient.createCollection).toHaveBeenCalled();
                    expect(fnCallback).toHaveBeenCalledWith(null, mockInitResponse);
                });
                
                it('throws error when services are failing, without making more calls than necessary', function () {
                    spyOn(collection._bootstrapClient, "getContent").andCallFake(fnServerError);
                    spyOn(collection._createClient, "createCollection").andCallFake(function (opts, errback) {
                        return;
                    });
                    
                    expect(function () {
                        collection.initFromBootstrap(fnCallback);
                    }).toThrow('Fatal collection connection error');
                    expect(collection._bootstrapClient.getContent.calls.length).toEqual(1);
                    expect(collection._createClient.createCollection).not.toHaveBeenCalled();
                });
                
                it('fails when there isn\'t an existing collection and a new collection can\'t be made', function () {
                    spyOn(collection._bootstrapClient, "getContent").andCallFake(fnFailedInit);
                    spyOn(collection._createClient, "createCollection").andCallFake(fnFailedCreate);
                    
                    collection.initFromBootstrap(fnCallback);
                    
                    expect(collection._bootstrapClient.getContent.calls.length).toEqual(1);
                    expect(collection._createClient.createCollection.calls.length).toEqual(1);
                });
            });

            describe('.createFeaturedContents', function () {
                it('returns a FeaturedContents object', function () {
                    var collection = new MockCollection({
                        withFeaturedInit: true
                    });
                    var featuredContents = collection.createFeaturedContents();
                    expect(featuredContents instanceof FeaturedContents).toBe(true);
                });
            });

            describe('.pause()', function () {
                var writable;
                beforeEach(function () {
                    writable = new Writable();
                    collection.createUpdater = function () {
                        var readable = new Readable();
                        readable._read = function () { this.push(null); };
                        return readable;
                    };
                    collection.createArchive = function () {
                        // Use a Dummy BootstrapClient to prevent requests
                        return Collection.prototype.createArchive.call(this, {
                            bootstrapClient: {
                                getContent: function (opts, errback) {
                                    errback(null, {});
                                }
                            }
                        });
                    };
                    writable._write = function (chunk, done) { done(); };
                });
                it('should work if called before any pipe', function () {
                    expect(function () {
                        collection.pause();
                    }).not.toThrow();
                });
                it('should pause ._updater if collection is piped', function () {
                    collection.pipe(writable);
                    expect(collection._updater.readable).toBe(true);
                    spyOn(collection._updater, 'pause').andCallThrough();
                    collection.pause();
                    expect(collection._updater.pause).toHaveBeenCalled();
                });
            });

            describe('.resume()', function () {
                var writable;
                beforeEach(function () {
                    writable = new Writable();
                    collection.createUpdater = function () {
                        var readable = new Readable();
                        readable._read = function () { this.push(null); };
                        return readable;
                    };
                    collection.createArchive = function () {
                        // Use a Dummy BootstrapClient to prevent requests
                        return Collection.prototype.createArchive.call(this, {
                            bootstrapClient: {
                                getContent: function (opts, errback) {
                                    errback(null, {});
                                }
                            }
                        });
                    };
                    writable._write = function (chunk, done) { done(); };
                });
                it('should work if called before any pipe', function () {
                    expect(function () {
                        collection.resume();
                    }).not.toThrow();
                });
                it('should resume ._updater if collection is piped', function () {
                    collection.pipe(writable);
                    expect(collection._updater.readable).toBe(true);
                    spyOn(collection._updater, 'resume').andCallThrough();
                    collection.resume();
                    expect(collection._updater.resume).toHaveBeenCalled();
                });
            });

            describe('.pipe(writable)', function () {
                var writable,
                    listView;
                beforeEach(function () {
                    writable = new Writable();
                    listView = new ContentListView();
                    collection.createUpdater = function () {
                        var readable = new Readable();
                        readable._read = function () { this.push(null); };
                        return readable;
                    };
                    collection.createArchive = function () {
                        // Use a Dummy BootstrapClient to prevent requests
                        return Collection.prototype.createArchive.call(this, {
                            bootstrapClient: {
                                getContent: function (opts, errback) {
                                    errback(null, {});
                                }
                            }
                        });
                    };
                    writable._write = function (chunk, done) { done(); };
                });
                it('can be piped to a writable', function () {
                    collection.pipe(writable);
                });
                describe('when piped to a ContentListView', function () {
                    it('pipes an updater to ContentListView', function () {
                        var onPipe = jasmine.createSpy('pipe');
                        listView.on('pipe', onPipe);
                        collection.pipe(listView);
                        expect(onPipe).toHaveBeenCalled();
                    });
                    it('pipes an archive to ContentListView#more', function () {
                        var onPipeToMore = jasmine.createSpy('pipe to more');
                        listView.more.on('pipe', onPipeToMore);
                        collection.pipe(listView);
                        expect(onPipeToMore).toHaveBeenCalledWith(jasmine.any(CollectionArchive));
                    });
                });
            });

            describe('.write()', function () {
                var mockWriteResponse = {"status": "ok", "code": 200, "data": {"messages": [{"content": {"replaces": null, "bodyHtml": "<p>oh hi there 2</p>", "annotations": {"moderator": true}, "source": 0, "authorId": "system@labs-t402.fyre.co", "parentId": null, "mentions": [], "shareLink": "http://t402.livefyre.com/.fyreit/w9lbch.4", "id": "26394571", "createdAt": 1363808885}, "vis": 1, "type": 0, "event": null, "source": 0}], "authors": {"system@labs-t402.fyre.co": {"displayName": "system", "tags": [], "profileUrl": "", "avatar": "http://gravatar.com/avatar/e23293c6dfc25b86762b045336233add/?s=50&d=http://d10g4z0y9q0fip.cloudfront.net/a/anon/50.jpg", "type": 1, "id": "system@labs-t402.fyre.co"}}}};
                var mockWriteTweetResponse = {"status": "ok", "code": 200, "data": {"messages": [{"content": {"replaces": "", "bodyHtml": "MAITRE GIMS : \" Les feat dans SUBLIMINAL ces du tres lourd j'veut pas trop m'avanc\u00e9 mais sa seras du tres lourd \"feat avec EMINEM &amp; 50 CENT?", "annotations": {}, "authorId": "471544268@twitter.com", "parentId": "", "updatedAt": 1366839025, "mentions": [], "shareLink": "http://fyre.it/QE0B9G.4", "id": "tweet-308280235000995842@twitter.com", "createdAt": 1366839025}, "vis": 1, "source": 0, "replies": [], "type": 0, "event": null}], "authors": {"471544268@twitter.com": {"displayName": "twinsley yonkou VX", "tags": [], "profileUrl": "https://twitter.com/#!/TismeyJr", "avatar": "http://a0.twimg.com/profile_images/3339939516/bde222e341d477729170a326ca31204e_normal.jpeg", "type": 3, "id": "471544268@twitter.com"}}}};
            
                beforeEach(function () {
                    collection._writer = collection.createWriter();
                    spyOn(collection._writer._writeClient, 'postContent').andCallFake(function (params, callback) {
                        if (callback) {
                            callback(null, mockWriteResponse);
                        }
                    });
                    spyOn(collection._writer._writeClient, 'postTweet').andCallFake(function (params, callback) {
                        if (callback) {
                            callback(null, mockWriteTweetResponse);
                        }
                    });
                });

                it('throws Auth.UnauthorizedError if a token is not set with streamhub-sdk/auth', function () {
                    expect(function () {
                        collection.write(new Content('blah'));
                    }).toThrow(new Auth.UnauthorizedError("Collection cannot write until streamhub-sdk/auth.setToken has been called"));
                });

                describe('when a token is set with streamhub-sdk/auth', function () {
                    var token;
                    beforeEach(function () {
                        token = '12345';
                        Auth.setToken(token);
                    });
                    afterEach(function () {
                        Auth.setToken();
                    });

                    it('can be called with Content', function () {
                        expect(function () {
                            collection.write(new Content('blah'));
                        }).not.toThrow();
                    });

                    it('writes into collection._writer', function () {
                        spyOn(collection._writer, 'write').andCallThrough();
                        collection.write(new Content('k'));
                        expect(collection._writer.write).toHaveBeenCalled();
                    });
                });
            });
        });
    });
});
